pub enum DrmSystem {
Common,
Widevine,
PlayReady,
}Expand description
A DRM protection system a pssh box can be generated for.
Variants
Common
W3C Common / clear-key family (urn:mpeg:dash:mp4protection).
Widevine
Google Widevine.
PlayReady
Microsoft PlayReady.
Implementations
Sourceimpl ProtectionSystem
impl ProtectionSystem
Sourcepub fn parse(name: &str) -> Option<ProtectionSystem>
pub fn parse(name: &str) -> Option<ProtectionSystem>
Parse a case-insensitive system name (as used on the command line).
Sourcepub fn pssh_box(self, key: &ContentKey, scheme: Scheme) -> Vec<u8> ⓘ
pub fn pssh_box(self, key: &ContentKey, scheme: Scheme) -> Vec<u8> ⓘ
Build the complete pssh box for this system, protecting key under
scheme.
Sourcepub fn pssh_box_ex(
self,
key: &ContentKey,
scheme: Scheme,
playready_extra: Option<&str>,
) -> Vec<u8> ⓘ
pub fn pssh_box_ex( self, key: &ContentKey, scheme: Scheme, playready_extra: Option<&str>, ) -> Vec<u8> ⓘ
Like Self::pssh_box, with optional extra PlayReady header XML
(Shaka --playready_extra_header_data) spliced into the WRMHEADER.